Learn R Programming

metagene (version 1.0.0)

binMatrix: Bin matrix columns

Description

This function will split a matrix into multiple segments.

Usage

binMatrix( data, binSize)

Arguments

data
The matrix to bin.
binSize
The number of nucleotides in each bin.

Value

binMatrix returns a matrix with each columns representing the mean of binSize nucleotides.

Examples

Run this code
  ## Not run: metagene:::binMatrix(matrix(1:40, nrow=4, ncol=10), 4)

Run the code above in your browser using DataLab