Learn R Programming

metagene (version 1.0.0)

bootstrapAnalysis: Perform the bootstrap analysis

Description

This function wraps the diffentent steps needed to do a bootstrap analysis on a matrix.

Usage

bootstrapAnalysis( currentMatrix, binSize, alpha, sampleSize, cores=1)

Arguments

currentMatrix
The matrix to use for the bootstrap analysis
binSize
The number of nucleotides in each bin for the bootstrap step.
alpha
Confidence interval.
sampleSize
Number of time each bin will be resampled ( hould be at least 1000).
cores
Number of cores for parallel processing (require parallel package).

Value

bootstrapAnalysis returns a list with the mean of the bootstraped vector and the quartile of order alpha/2 and (1-alpha/2).

Examples

Run this code
  ## Not run: metagene:::bootstrapAnalysis(matrix(1:40, nrow=4, ncol=10), 4, alpha=0.05, sampleSize=100)

Run the code above in your browser using DataLab