Learn R Programming

metagene (version 1.0.0)

getDataFrame: Convert the bootstrapped data into a data.frame

Description

This function will convert the results of the bootstrap analysis into a data.frame that can be used directly with ggplot2 to produce the final plot.

Usage

getDataFrame(bootstrapData, range, binSize)

Arguments

bootstrapData
Data produced during the bootstrap analysis
range
The start and the end for the x-label
binSize
The number of nucleotides in each bin for the bootstrap step.

Value

getDataFrame a data.frame with the condensed results from the main data structure.Columns: * Groups: name of current group * distances: the number of bin for each entry * means: the means to plot * qinf: the lower end of the confidence interval * qsup: the higher end of the confidence interval

Examples

Run this code
  # Get bootstrap results
  ## Not run: bootstrapResults <- list()
  ## Not run: bootstrapResults$a <- metagene:::bootstrapAnalysis(matrix(1:40, nrow=4, ncol=10), 4, alpha=0.05, sampleSize=100)

  # Get the data.frame
  ## Not run: DF <- metagene:::getDataFrame(bootstrapResults, c(-1,1))

Run the code above in your browser using DataLab