Learn R Programming

metagene (version 1.0.0)

getGenes: Fetch the annotation of all genes.

Description

This function will fetch the positions of all known coding genes for a given specie. Currently supported species are: “mouse”, “human” (default).

Usage

getGenes( specie="human")

Arguments

specie
human: Homo sapiens (default) / mouse: Mus musculus

Value

getGenes return a GRanges object with a feature metadata that correspond to the ensembl_gene_id.

Details

This function will fetch all the ensembl_gene_id for a given specie ("human" or "mouse").

Examples

Run this code
  ## Not run: knownGenes <- getGenes("human")

Run the code above in your browser using DataLab