Learn R Programming

metagene (version 2.0.0)

getGenesBiomart: Fetch the annotation of all genes from biomart.

Description

This function will fetch the positions of all known coding genes for a given specie. Currently supported species are: “mouse”, “human” (default).

This function was used to create external datasets for the getGenes function.

Usage

getGenesBiomart( specie="human")

Arguments

specie
human: Homo sapiens (default) / mouse: Mus musculus

Value

getGenesBiomart return a GRanges object with a feature metadata that corresponds to emsembl_gene_id.

Details

Using biomaRt package, this function will fetch all the ensembl_gene_id for a given specie ("human" or "mouse").

Examples

Run this code
  ## Not run: knownGenes <- getGenesBiomart("human")

Run the code above in your browser using DataLab