Learn R Programming

metagene (version 1.0.0)

mergeMatrix: Convert list of vectors in matrix for a single group

Description

This function combine a list of list of vectors. The first step is to merge every list of vector in a group into a matrix. Then every matrices in the same group are combined.

Usage

mergeMatrix( group, level)

Arguments

group
Correspond to an element in the data subsection of the main data structure.
level
The names of the element to merge.

Value

mergeMatrix returns the group element from the arguments with an extra element named matrix.

Details

Pre-calculated features (such as transcription start sites of protein coding gene or enhancer) are available. Bam files are used to increase the resolution. Multiple combination of group of features and or group of bam files can be compared in a single analysis. Bootstraping analysis is used to compare the groups and locate regions with statistically different enrichment profiles.

Examples

Run this code
  # Create the lists of vector
  ## Not run: vector1 <- list(c(1,2,3,4), c(5,6,7,8))
  ## Not run: vector2 <- list(c(9,10,11,12), c(13,14,15,16))

  # Add them to a list
  ## Not run: group <- list()
  ## Not run: group$vectors <- list(vector1, vector2)

  # We will modify the group objet to add an element names
  # matrix that contains the matrix that correspond to the
  # vectors binded by row
  ## Not run: metagene:::mergeMatrix(group, "vectors")

Run the code above in your browser using DataLab