Learn R Programming

metagene (version 1.0.0)

plotGraphic: Produce a plot with based on a data.frame

Description

This function will produce the final plot for an analysis.

Usage

plotGraphic( DF, title, binSize)

Arguments

DF
The data frame produced by the getDataFrame function
title
The title of the graph
binSize
The number of nucleotides in each bin for the bootstrap step.

Value

plotGraphic plots a graph on the current device.

Examples

Run this code
  ## Not run: DF <- data.frame(Groups=rep("group1",11), distances=seq(-5,5), means=rep(30, 11), qinf=rep(20, 11), qsup=rep(40, 11))
  ## Not run: metagene:::plotGraphic(DF, "Example")

Run the code above in your browser using DataLab