Learn R Programming

metagene (version 1.0.0)

plotMatrices: Create a graph

Description

This function wraps all the steps necessary to produce the final plot using the results of either parseFeatures or parseRegions functions.

Usage

plotMatrices( matricesGroups, data, binSize=100, alpha=0.05, sampleSize=1000, cores=1)

Arguments

matricesGroups
A list with every groups to include in the graph. A group is one or more combination of featureGroup/designGroup. The names must correspond to the names of the matrix object returned from the parse functions (parseFeatures or parseRegions).
data
The object returned by the parse functions. (parseFeatures or parseRegions).
binSize
The number of nucleotides in each bin for the bootstrap step.
alpha
Confidence interval.
sampleSize
Number of time each bin will be resampled ( hould be at least 1000).
cores
Number of cores for parallel processing (require parallel package).

Value

plotMatrices return the data.frame used to produce the graph.

Examples

Run this code
  # Prepare the groups
  bamFileName <- system.file("extdata/align1_rep1.bam", package="metagene")
  listFileName <- system.file("extdata/list1.txt", package="metagene")
  groups <- parseFeatures(bamFileName, listFileName, specie="mouse")

  # Do the graph
  DF <- plotMatrices(list(g1="list1"), groups)

Run the code above in your browser using DataLab