Learn R Programming

metagene (version 1.0.0)

prepareFeatures: Convert a list of IDs into a GRangesList

Description

This function will convert a list of Ensembl Gene IDs into a list of regions.

Usage

prepareFeatures( features, specie="human", maxDistance=5000, cores=1)

Arguments

features
Either a filename of a vector of filenames. Supported features: ensembl_gene_id If value is NULL: every ensembl_gene_id will be returned.
specie
human: Homo sapiens (default) / mouse: Mus musculus
maxDistance
The distance around features to include in the plot.
cores
Number of cores for parallel processing (require parallel package).

Value

prepareFeatures returns a list of GRangesList. One GRanges by group of features. The names of each GRanges of the list correspond to the name of the group.

Examples

Run this code
  # Load a feature file
  ## Not run: featuresFileName <- system.file("extdata/list1.txt", package="metagene")
  ## Not run: features <- metagene:::prepareFeatures(featuresFileName, specie="mouse")

Run the code above in your browser using DataLab