Learn R Programming

metagene (version 1.0.0)

prepareGroups: Distribute the bam filenames in their respective groups.

Description

This function will initialize every groups in the main data structure.

Usage

prepareGroups( featuresGroupsNames, bamFiles, design=NULL)

Arguments

featuresGroupsNames
The name of the group of features in the current analysis.
bamFiles
A vector of bam filename(s).
design
A matrix explaining the relationship between multiple samples. * One line per samples. * One column per group of samples. For example, biological replicates and corresponding controls are in the same group. 1: treatment file(s) 2: control file(s)

Value

prepareGroups returns a list of list of list.