Learn R Programming

metagene (version 1.0.0)

prepareRegions: Parse bed files and convert them in a list of GRangesList.

Description

This function will convert a bed files into a GRangesList.

Usage

prepareRegions( regions, cores=1)

Arguments

regions
A vector of bed file names corresponding to the regions to include in the analysis. The file name (minus the extension) will be used as the name of the region.
cores
Number of cores for parallel processing (require parallel package).

Value

prepareRegions returns a GRangesList. One GRanges by group of features. The names of each element of the list correspond to the name of the group.

Examples

Run this code
  ## Not run: regionsFileName <- system.file("extdata/list1.bed", package="metagene")
  ## Not run: regions <- metagene:::prepareRegions(regionsFileName)

Run the code above in your browser using DataLab