Learn R Programming

metagene (version 1.0.0)

scaleVector: Scale the values of a vector to fit with predetermined size

Description

This function will resize the values of the vector so that they fit in a pre-defined range. The number of elements will changed, but the general distribution will remain the same.

Usage

scaleVector( values, domain)

Arguments

values
the values to scale
domain
the range to fit the value to

Value

scaleVector returns a vector with the scaled data

Examples

Run this code
  ## Not run: values <- 1:10
  ## Not run: scaledValues <- metagene:::scaleVector(values, 100)

Run the code above in your browser using DataLab