binBootstrap:
Estimate mean and confidence interval of a column using bootstrap.
Description
Since the sample size can be small, the use of a bootstrap
function can help to calculate a better approximation of the
mean and reduce the confidence intervals.
Usage
binBootstrap( data, alpha, sampleSize, cores=1)
Arguments
data
A vector representing a column from the binned
matrix.
alpha
Confidence interval.
sampleSize
Number of time each bin will be resampled (
hould be at least 1000).
cores
Number of cores for parallel processing (require
parallel package).
Value
binBootstrap returns a list with the mean of the bootstrapped
vector and the quartile of order alpha/2 and (1-alpha/2)