plotGraphic function. Currently supported species are:
mouse, human (default).
parseFeatures( bamFiles, features=NULL, specie="human", maxDistance=5000, design=NULL, cores=1, debug=FALSE)vector of BAM files to plot. All BAM files
must exist.vector of filenames.
Supported features: ensembl_gene_id.
If value is NULL, all known RefSeq genes will be used.data.frame explaining the relationship
between multiple samples. One line per samples. One column
per group of samples. For example, biological replicates and
corresponding controls are in the same group.
1: treatment file(s). 2: control file(s).parseFeatures returns a list that contains the data
necessary to produce a plot.The data structure is a list of lists.The first level contain the following fields:
data.frame with the
following columns:
The values are normalized as read per millions aligned (RPM).
It is possible to parse multiple groups of gene by saving each
list in a separate file and by listing the file names in a
vector as the features parameter.
By using the design parameter, the parseFeatures
function will deal with more complex experimental design such
as the use of replicates and/or controls. The values of
controls are substracted from every replicates.
bamFileName <- system.file("extdata/align1_rep1.bam", package="metagene")
featuresFileName <- system.file("extdata/list1.txt", package="metagene")
groups <- parseFeatures(bamFileName, featuresFileName, specie="mouse")
Run the code above in your browser using DataLab